ibu
===============================

Overview
--------

A database agnotics migration and data export tool. WIP

Installation / Usage
--------------------

To install use pip:

    $ pip install ibu


Or clone the repo:

    $ git clone https://github.com/ojengwa/ibu.git

    $ python setup.py install

Contributing
------------

TBD

Example
-------

TBD


